# -*- coding: utf-8 -*-
from __future__ import unicode_literals

import re

from pmxbot_wolframalpha import wa

class Empty(object):
	"""
	Passed in to the individual commands instead of a client/event because
	we don't normally care about them
	"""
	pass

c = Empty()
e = Empty()

class TestCommands(object):
	def test_wolframalpha_simple(self):
		"""
		Basic wolframalpha command - 1+1 must include 2 in results
		"""
		res = wa(c, e, "#test", "testrunner", "1+1")
		assert "2" in res

	def test_wolframalpha_complicated(self):
		"""
		More complicated wolframalpha command - 40 gallons in liters must
		include 151.4 in results
		"""
		res = wa(c, e, "#test", "testrunner", "40 gallons in liters")
		assert "151.4" in res

	def test_wolframalpha_supercomplicated(self):
		"""
		Supercomplicated wolframalpha command - 502 hogsheads per mile in
		litres per km
		include 74 388.9641 in results
		"""
		res = wa(c, e, "#test", "testrunner",
			"502 hogsheads per mile in litres per km")
		assert "74" in res and ('388.' in res or '389' in res)

	def test_wolframalpha_currency_usd_gbp(self):
		"""
		Test that wolframalpha for a currency conversion: 1 USD in GBP
		"""
		res = wa(c, e, "#test", "testrunner", "1 USD in GBP")
		pattern = '£\d+\.\d+\s+' + re.escape('(British pounds)')
		assert re.match(pattern, res)

	def test_wolframalpha_currency_czk_euro(self):
		"""
		Test that wolframalpha for a currency conversion: 12 CZK in euros
		"""
		res = wa(c, e, "#test", "testrunner", "12 CZK in euros")
		pattern = 'euro\d+\.\d+\s+' + re.escape('(euros)')
		assert re.match(pattern, res)
